| Title: | Quality metrics for ChIPseq data |
|---|---|
| Description: | Quality metrics for ChIPseq data. |
| Authors: | Tom Carroll, Wei Liu, Ines de Santiago, Rory Stark |
| Maintainer: | Tom Carroll <[email protected]>, Rory Stark <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.49.3 |
| Built: | 2026-05-20 19:27:44 UTC |
| Source: | https://github.com/bioc/ChIPQC |
ChIPQC analyzes aligned reads (in .bam format) for ChIP-seq samples and their associated controls, computing a variety of quality control metrics and statistics, and providing reporting and plotting functions to enable assessment of experimental data for further analysis.
| Package: | ChIPQC |
| Type: | Package |
| Version: | 0.1 |
| Date: | 2014-03-01 |
| License: | GPL3 |
ChIPQC primarily uses two object classes: ChIPQCsample, which encapsulates the information about individual samples, and ChIPQCexperiment, which encapsulates information about larger ChIP-seq experiments (consisting of a number of samples). The primary entry point is the constructor function ChIPQC, which takes a description of an entire experiment, constructs objects for all the samples, and computes the quality metrics.
Tom Carroll and Rory Stark
Maintainers: Tom Carroll <[email protected]> and Rory Stark <[email protected]>
Frontiers?
ChIPQC is designed to work closely with the DiffBind package, which provides functionality for analyzing ChIP-seq experiments, including performing differential binding analysis to identify significantly differentially bound peaks.
Retrieve the average peak profile for a sample or set of samples.
signature(object = "ChIPQCexperiment")Retrieve a matrix of the average peak profiles for all of the samples in an ChIP-seq experiment. Each column represents a sample, and each row a base pair position, centered on peak summits.
signature(object = "list")Retrieve a matrix of the average peak profiles for all of the samples in a list of ChIPQC samples. Each column represents a sample, and each row a base pair position, centered on peak summits.
signature(object = "ChIPQCsample")Retrieve a vector representing the average peak profile for a sample. Each column represents a basepair position, centered on the peak summits.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) CTCFprofile = averagepeaksignal(QCsample(exampleExp,1)) length(CTCFprofile) plot(CTCFprofile,type='l',ylab="mean pileup") allprofiles = averagepeaksignal(exampleExp) dim(allprofiles) for(i in 1:ncol(allprofiles)) lines(allprofiles[,i],col=i)data(example_QCexperiment) CTCFprofile = averagepeaksignal(QCsample(exampleExp,1)) length(CTCFprofile) plot(CTCFprofile,type='l',ylab="mean pileup") allprofiles = averagepeaksignal(exampleExp) dim(allprofiles) for(i in 1:ncol(allprofiles)) lines(allprofiles[,i],col=i)
ChIPQCexperiment object
Constructs a new ChIPQCexperiment object.
ChIPQC(experiment, annotation, chromosomes, samples, consensus=FALSE, bCount=FALSE, mapQCth=15, blacklist=NULL, profileWin=400, fragmentLength=125, shifts=1:300, ...)ChIPQC(experiment, annotation, chromosomes, samples, consensus=FALSE, bCount=FALSE, mapQCth=15, blacklist=NULL, profileWin=400, fragmentLength=125, shifts=1:300, ...)
experiment |
A specification of the ChIP-seq experiment to evaluate.
This can either be a dataframe, a filename for a .csv file,
or a
See the documentation for the |
annotation |
Either a character string indicating the genome and version to use as a genomic annotation, or a previously defined annotation (obtained using
Alternatively, you can construct your own annotation; see the package vignette for more information. |
chromosomes |
Specification of which chromosomes to use for computing QC statistics. If missing, the first chromosome which has a peak is checked. If NULL, all chromosomes will be checked (which may be time-consuming). This can be a character string (e.g. “chr18”) or a vector or list of character strings. If it is an integer or vector of integers, the chromosomes will be checked based on the order that they are listed in a peak set. |
samples |
|
consensus |
If |
bCount |
if |
mapQCth |
An integer representing a mapping quality score threshold. Only reads with mapping quality scores above this threshold will be used for some statistics. |
blacklist |
A |
profileWin |
An integer indicating the width, in base pairs, of the window to be used for peak profiles. Peaks will be centered on their summits, and include half the window size upstream and half downstream of this point. |
fragmentLength |
An integer indicating the expected fragment length of the libraries. Optional, as this value will be computed for each library. |
shifts |
A vector of values to try when computing optimal shift sizes. |
... |
additional parameters passed to |
ChIPQC first constructs a new DBA-object object
if one is not provided.
Next it computes the annotation if one is not provided.
The main loop constructs new ChIPQCsample objects for
each sample (and unique control sample).
A ChIPQCexperiment object.
ChIPQC uses bplapply from the BiocParallel package to build the ChIPQCsample object in parallel, if supported. Control of the parallelization can be effected using BiocParallel functions, such as register.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample, DiffBind
## Not run: exampleExp = ChIPQC(samples,annotation="hg19") data(example_QCexperiment) exampleExp ## Not run: tamoxifen = ChIPQC(samples, ,annotation="hg19", consensus=TRUE, bCounts=T) data(tamoxifen_QC) tamoxifen## Not run: exampleExp = ChIPQC(samples,annotation="hg19") data(example_QCexperiment) exampleExp ## Not run: tamoxifen = ChIPQC(samples, ,annotation="hg19", consensus=TRUE, bCounts=T) data(tamoxifen_QC) tamoxifen
ChIPQC package, each containing a ChIPQCexperiment object, as well as a pre-compiled blacklist for hg19.
The tamoxifen_QC example data set contains a ChIPQCexperiment object named tamoxifen. This data set, based on Ross-Innes et al (2012), includes 11 ER ChIP libraries, and their input controls, divided into tamoxifen responsive and tamoxifen resistant sample groups. Only data for chromosome 18 (chr18) are included.
The example_QCexperiment data set contains a ChIPQCexperiment object named exampleExp. This data set, derived from ENCODE data, includes 6 ChIP libraries. Only data for chromosome 22 (chr22) are included.
blacklist_hg19 data set includes a GRanges object named blacklist_hg19 containing blacklisted regions for the human genome, derived from the UCSC blacklist.
data(tamoxifen_QC) data(example_QCexperiment) data(blacklist_hg19)data(tamoxifen_QC) data(example_QCexperiment) data(blacklist_hg19)
tamoxifen_QC: A single ChIPQCexperiment object named tamoxifen is loaded. This object is used for the ChIPQC-package examples and vignette. This object can also be used with the DiffBind package (see related data objects tamoxifen).
example_QCexperiment: A single ChIPQCexperiment object named exampleExp is loaded. This object is used for the ChIPQC-package examples and vignette.
blacklist_hg19: A single GRanges object named blacklist.hg19 that is used by default when processing hg19 data sets.
Ross-Innes, C. S., Stark, R., Teschendorff, A. E., Holmes, K. A., Ali, H. R., Dunning, M. J., Brown, G. D., Gojis, O., Ellis, I. O., Green, A. R., Ali, S., Chin, S.-F., Palmieri, C., Caldas, C., and Carroll, J. S. (2012). Differential oestrogen receptor binding is associated with clinical outcome in breast cancer. Nature 481, 389-393.
data(tamoxifen_QC) tamoxifen plotRegi(tamoxifen) data(example_QCexperiment) exampleExp data(blacklist_hg19) blacklist.hg19data(tamoxifen_QC) tamoxifen plotRegi(tamoxifen) data(example_QCexperiment) exampleExp data(blacklist_hg19) blacklist.hg19
These functions are provided for compatibility with older versions of ‘ChIPQC’ only, and will be defunct at the next release.
The following functions are deprecated and will be made defunct in the next Bioconductor release cycle:
ChIPQCreport: there is no replacement function.
The Nozzle.R1 CRAN package that ChIPQCreport
depended on for HTML report generation is no longer available
and cannot be installed. ChIP-seq quality metrics are still
available through the exported accessor methods
(QCmetrics, coveragehistogram,
crosscoverage, flagtagcounts,
fragmentlength, ssd,
frip, etc.). For visual ChIP-seq QC reports, the
deeptools
Python package is the de facto standard. The original
ChIPQCreport source code is preserved in
inst/legacy/report.r and can be accessed via
system.file("legacy/report.r", package = "ChIPQC") for
reference and possible future revival.
The ChIPQCexperiment class is built around a list of ChIPQCsample objects, each representing a ChIP or control sample in a ChIP-seq experiment. These objects are created using the ChIPQC function.
.Data:Object of class "list": internal
Samples:Object of class "list": List of ChIPQCsample objects.
DBA:Object of class "DBA": DBA-object object (from package DiffBind)
annotation:Object of class "list" : annotation data
Class "list".
signature(object = "ChIPQCexperiment"): see QCmetadata.
signature(object = "ChIPQCexperiment"): see QCmetrics.
signature(object = "ChIPQCexperiment"): see QCsample.
signature(object = "ChIPQCexperiment"): see QCcontrol.
signature(object = "ChIPQCexperiment"): see QCannotation.
signature(object = "ChIPQCexperiment"): see QCdba.
signature(object = "ChIPQCexperiment"): see averagepeaksignal.
signature(object = "ChIPQCexperiment"): see coveragehistogram.
signature(object = "ChIPQCexperiment"): see crosscoverage.
signature(object = "ChIPQCexperiment"): see flagtagcounts.
signature(object = "ChIPQCexperiment"): see fragmentlength.
signature(object = "ChIPQCexperiment"): see FragmentLengthCrossCoverage.
signature(object = "ChIPQCexperiment"): see frip.
signature(object = "ChIPQCexperiment"): see mapped.
signature(object = "ChIPQCexperiment"): see reads.
signature(object = "ChIPQCexperiment"): see duplicates.
signature(object = "ChIPQCexperiment"): see duplicateRate.
signature(object = "ChIPQCexperiment"): see Normalisedaveragepeaksignal.
signature(object = "ChIPQCexperiment"):see peaks.
signature(object = "ChIPQCexperiment"): see readlength.
signature(object = "ChIPQCexperiment"): see ReadLengthCrossCoverage.
signature(object = "ChIPQCexperiment"):see RelativeCrossCoverage.
signature(object = "ChIPQCexperiment"): see ribl.
signature(object = "ChIPQCexperiment"): see rip.
signature(object = "ChIPQCexperiment"): see show.
signature(object = "ChIPQCexperiment"): see ssd.
signature(object = "ChIPQCexperiment"): see regi.
signature(object = "ChIPQCexperiment"): see plotCC.
signature(object = "ChIPQCexperiment"): see plotCoverageHist.
signature(object = "ChIPQCexperiment"): see plotFribl.
signature(object = "ChIPQCexperiment"): see plotPeakProfile.
signature(object = "ChIPQCexperiment"): see plotRap.
signature(object = "ChIPQCexperiment"): see plotRegi.
signature(object = "ChIPQCexperiment"): see plotCorHeatmap.
signature(object = "ChIPQCexperiment"): see plotPrincomp.
signature(object = "ChIPQCexperiment"): see ChIPQCreport.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCsample, DiffBind
## Not run: exampleExp = ChIPQC(samples) data(example_QCexperiment) exampleExp ## Not run: tamoxifen = ChIPQC(samples, consensus=TRUE, bCounts=T) data(tamoxifen_QC) tamoxifen## Not run: exampleExp = ChIPQC(samples) data(example_QCexperiment) exampleExp ## Not run: tamoxifen = ChIPQC(samples, consensus=TRUE, bCounts=T) data(tamoxifen_QC) tamoxifen
Generate an HTML summary QC report.
signature(experiment = "ChIPQCexperiment", facet=TRUE,
reportName="ChIPQC", reportFolder="ChIPQCreport",
facetBy=c("Tissue","Factor","Condition","Treatment"),
colourBy=c("Replicate"))Generates an summary QC report for the experiment in HTML format.
| experiment | ChIPQCexperiment object |
| facet | logical indicating whether or not to facet using experimental metadata. |
| reportName | filename of main report file (.html). |
| reportFolder | directory name where plot graphics will be saved |
| facetBy | metadata fields to use for faceting |
| colourBy | metadata field to color by |
signature(experiment = "list", facet=TRUE,
reportName="ChIPQC", reportFolder="ChIPQCreport",
facetBy=c("Sample"),
colourBy=c("Sample"))Generates an summary QC report for a list of ChIPQCsample objects in HTML format.
| experiment | list object |
| facet | logical indicating whether or not to facet using experimental metadata. |
| reportName | filename of main report file (.html). |
| reportFolder | directory name where plot graphics will be saved |
| facetBy | metadata fields to use for faceting |
| colourBy | metadata field to color by |
signature(sample = "ChIPQCsample",
reportName="ChIPQC", reportFolder="ChIPQCreport",)Generate a summary QC report for a sample in HTML format.
| sample | ChIPQCsample object |
| reportName | filename of main report file (.html). |
| reportFolder | directory name where plot graphics will be saved |
ChIPQCreport is deprecated as of ChIPQC 1.49.1. The
Nozzle.R1 CRAN package it depended on for HTML report
generation is no longer available. See
?'ChIPQC-deprecated' for replacements (QC accessor
methods; deeptools for visual reports). The original
implementation is preserved at
system.file("legacy/report.r", package = "ChIPQC").
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
"ChIPQCsample"
Object containing quality metrics computed for a ChIP-seq (or associated control) sample.
Objects can be created using the ChIPQCsample function.
ChIPQCsample(reads, peaks, annotation, chromosomes = NULL, mapQCth = 15,
blacklist, profileWin = 400, fragmentLength = 125, shifts = 1:300,
runCrossCor = FALSE,verboseT=FALSE)
readscharacter string filename of .bam file
peaksGRanges object or character string filename of peaks. If present, peak-based metrics will be computed.
annotationEither a character string indicating the genome and version to use as a genomic annotation, or a previously defined annotation (obtained using QCannotation on a previously defined ChIPQCexperiment object.) May be left unspecified, in which case no genomic feature analysis is performed. The following annotation specifiers are supported:
| "hg20" | Human, version 20 |
| "hg19" | Human, version 19 |
| "hg18" | Human, version 18 |
| "mm10" | Mouse, version 10 |
| "mm9" | Mouse, version 19 |
| "rn4" | Rat, version 4 |
| "ce6" | C. Elgans, version 6 |
| "dm3" | D. Melanogaster, version 3 |
Alternatively, you can construct your own annotation; see the package Vignette for more information.
chromosomesSpecification of which chromosomes to use for computing QC statistics. If missing, the first chromosome which has a peak is checked. If NULL, all chromosomes will be checked (which may be time-consuming). This can be a character string (e.g. “chr18”) or a vector or list of character strings. If it is an integer or vector of integers, the chromosomes will be checked based on the order that they are listed in a peak set.
mapQCthAn integer representing a mapping quality score threshold. Only reads with mapping quality scores above this threshold will be used for some statistics.
blacklistA GRanges object or filename specifying a bed file containing genomic regions that should be excluded from the analysis. If missing and the annotation is “hg19”, a default blacklist, blacklist_hg19 derived from the UCSC list, will be used. No blacklist is used if this is set to NULL, or is left missing and the annotation is not “hg19”.
profileWinAn integer indicating the width, in base pairs, of the window to be used for peak profiles. Peaks will be centered on their summits, and include half the window size upstream and half downstream of this point.
fragmentLengthAn integer indicating the expected fragment length of the libraries. Optional, as this value will be computed.
shiftsA vector of values to try when computing optimal shift sizes.
runCrossCorCompute cross-correlation in addition to cross-coverage. This will take more compute time, and is currently not used in the final report.
verboseTTRUE or FALSE, specifying whether to report progress. Default is TRUE. When set to FALSE ChIPQC does not report any progress until complete.
AveragePeakSignal:Object of class "list"
CrossCoverage:Object of class "numeric"
CrossCorrelation:Object of class "numeric"
SSD:Object of class "numeric"
SSDBL:Object of class "numeric"
CountsInPeaks:Object of class "numeric"
CountsInBlackList:Object of class "numeric"
CountsInFeatures:Object of class "list"
PropInFeatures:Object of class "list"
CoverageHistogram:Object of class "numeric"
FlagAndTagCounts:Object of class "numeric"
readlength:Object of class "numeric"
seqnames:Object of class "Rle"
ranges:Object of class "IRanges"
strand:Object of class "Rle"
elementMetadata:Object of class "DataFrame"
seqinfo:Object of class "Seqinfo"
metadata:Object of class "list"
Class "GRanges"
signature(object = "ChIPQCsample"): see averagepeaksignal.
signature(object = "ChIPQCsample"): see coveragehistogram.
signature(object = "ChIPQCsample"): see crosscoverage.
signature(object = "ChIPQCsample"): see flagtagcounts.
signature(object = "ChIPQCsample"): see fragmentlength.
signature(object = "ChIPQCsample"): see FragmentLengthCrossCoverage.
signature(object = "ChIPQCsample"): see frip.
signature(object = "ChIPQCsample"): see mapped.
signature(object = "ChIPQCsample"): see reads.
signature(object = "ChIPQCsample"): see duplicates.
signature(object = "ChIPQCsample"): see duplicateRate.
signature(object = "ChIPQCsample"): see Normalisedaveragepeaksignal.
signature(object = "ChIPQCsample"):see peaks.
signature(object = "ChIPQCsample"): see readlength.
signature(object = "ChIPQCsample"): see ReadLengthCrossCoverage.
signature(object = "ChIPQCsample"):see RelativeCrossCoverage.
signature(object = "ChIPQCsample"): see ribl.
signature(object = "ChIPQCsample"): see rip.
signature(object = "ChIPQCsample"): see show.
signature(object = "ChIPQCsample"): see ssd.
signature(object = "ChIPQCsample"): see regi.
signature(object = "ChIPQCsample"): see plotCC.
signature(object = "ChIPQCsample"): see plotCoverageHist.
signature(object = "ChIPQCsample"): see plotFribl.
signature(object = "ChIPQCsample"): see plotPeakProfile.
signature(object = "ChIPQCsample"): see plotRap.
signature(object = "ChIPQCsample"): see plotRegi.
Thomas Carroll and Rory Stark
Carroll TS, Liang Z, Salama R, Stark R and Santiago Id (in press). Impact of artefact removal on ChIP quality metrics in ChIP-seq and ChIP-exo data. Frontiers in Genetics.
bamFile <- system.file("extdata", "ex1.bam", package="Rsamtools") ex1 <- ChIPQCsample(bamFile,annotation=NULL) readlength(ex1) fragmentlength(ex1)bamFile <- system.file("extdata", "ex1.bam", package="Rsamtools") ex1 <- ChIPQCsample(bamFile,annotation=NULL) readlength(ex1) fragmentlength(ex1)
Retrieve histogram data representing densities of coverage pileups.
signature(object = "ChIPQCexperiment")Retrieve a matrix of coverage histogram data for all samples in a ChIP-seq experiment. Each column represents a sample, and each row a pileup height, with the value representing the number of basepair positions that report this pileup height.
signature(object = "list")Retrieve a matrix of coverage histogram data for all ChIPQCsamples in a list. Each column represents a sample, and each row a pileup height, with the value representing the number of basepair positions that report this pileup height.
signature(object = "ChIPQCsample")Retrieve a vector representing coverage histogram data for a sample. Values represent the number of base pairs positions that report the pileup value. The value in position 1 of the vector the contains the number of examined basepair positions that are overlapped by exactly zero reads, while position 2 shows the number of basepair positions overlapped by exactly one read, etc.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) CTCFcoverage = coveragehistogram(QCsample(exampleExp,1)) length(CTCFcoverage) plot(log10(CTCFcoverage),type='l',ylab="log10 Density", xlab="Pileup") allcoverages = coveragehistogram(exampleExp) dim(allcoverages) for(i in 1:ncol(allcoverages)) lines(log10(allcoverages[,i]),col=i)data(example_QCexperiment) CTCFcoverage = coveragehistogram(QCsample(exampleExp,1)) length(CTCFcoverage) plot(log10(CTCFcoverage),type='l',ylab="log10 Density", xlab="Pileup") allcoverages = coveragehistogram(exampleExp) dim(allcoverages) for(i in 1:ncol(allcoverages)) lines(log10(allcoverages[,i]),col=i)
Retrieves the cross-coverage values for a range of shift sizes.
signature(object = "ChIPQCexperiment")Retrieve a matrix of cross-coverage data for all samples in an ChIP-seq experiment. Each column represents a sample, and each row a shift size, with the value representing the cross-coverage using that size read.
signature(object = "list")Retrieve a matrix of cross-coverage data for all samples in a list of ChIPQCsample objects. Each column represents a sample, and each row a shift size, with the value representing the cross-coverage using that size read.
signature(object = "ChIPQCsample")Retrieve a vector of cross-coverage data for a sample. Each position in the vector corresponds to a shift size, with the value representing the cross-coverage using that size read.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) CTCFcoverage = crosscoverage(QCsample(exampleExp,1)) length(CTCFcoverage) plot(CTCFcoverage,type='l', ylab="Cross-coverage", xlab="Fragment length") allcoverages = crosscoverage(exampleExp) dim(allcoverages) for(i in 1:ncol(allcoverages)) lines(allcoverages[,i],col=i)data(example_QCexperiment) CTCFcoverage = crosscoverage(QCsample(exampleExp,1)) length(CTCFcoverage) plot(CTCFcoverage,type='l', ylab="Cross-coverage", xlab="Fragment length") allcoverages = crosscoverage(exampleExp) dim(allcoverages) for(i in 1:ncol(allcoverages)) lines(allcoverages[,i],col=i)
Retrieve duplication rates.
signature(object = "ChIPQCexperiment", bFiltered)Retrieve a vector of the duplication rates for each sample in an experiment. A read is considered duplicated if another read maps to the same genomic location; the duplication rate is the number of duplicated reads divided by the total number of reads for a sample. If bFiltered=TRUE (or is missing), only reads that pass the mapping quality filter for each sample are included. if bFiltered=FALSE, all reads for each sample will be included.
signature(object = "list", bFiltered)Retrieve a vector of the duplication rates for each sample in a list of ChIPQCsample objects. A read is considered duplicated if another read maps to the same genomic location; the duplication rate is the number of duplicated reads divided by the total number of reads for a sample. If bFiltered=TRUE (or is missing), only reads that pass the mapping quality filter for each sample are included. if bFiltered=FALSE, all reads for each sample will be included.
signature(object = "ChIPQCsample", bFiltered)Retrieve the duplication rate for a sample. A read is considered duplicated if another read maps to the same genomic location; the duplication rate is the number of duplicated reads divided by the total number of reads for the sample. If bFiltered=TRUE (or is missing), only reads that pass the mapping quality filter for the sample are included. if bFiltered=FALSE, all reads for the sample will be included.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) duplicateRate(exampleExp) duplicateRate(QCsample(exampleExp,1))data(example_QCexperiment) duplicateRate(exampleExp) duplicateRate(QCsample(exampleExp,1))
Retrieve the numbers of duplicate reads.
signature(object = "ChIPQCexperiment", bFiltered)Retrieve a vector of the numbers of duplicate reads for each sample in an experiment. A read is considered duplicated if another read maps to the same genomic location. If bFiltered=TRUE (or is missing), this will be the number of duplicates that pass the mapping quality filter for each sample. if bFiltered=FALSE, it will be the total number of duplicates for each sample.
signature(object = "list", bFiltered)Retrieve a vector of the numbers of duplicate reads for each sample in a list of ChIPQCsample objects. A read is considered duplicated if another read maps to the same genomic location. If bFiltered=TRUE (or is missing), this will be the number of duplicates that pass the mapping quality filter for each sample. if bFiltered=FALSE, it will be the total number of duplicates for each sample.
signature(object = "ChIPQCsample", bFiltered)Retrieve the number of duplicates for a sample. A read is considered duplicated if another read maps to the same genomic location. If bFiltered=TRUE (or is missing), this will be the number of duplicates that pass the mapping quality filter. if bFiltered=FALSE, it will be the total number of duplicates for the sample.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) duplicates(exampleExp) duplicates(QCsample(exampleExp,1))data(example_QCexperiment) duplicates(exampleExp) duplicates(QCsample(exampleExp,1))
Retrieve numbers of reads that pass various filters
signature(object = "ChIPQCexperiment")Retrieve a matrix of counts passing various filters for all the samples in an experiment. Each column represents the counts in a sample.
signature(object = "list")Retrieve a matrix of counts passing various filters for all the samples in a list of ChIPQCsample objects. Each column represents the counts in a sample.
signature(object = "ChIPQCsample")Retrieve a vector of counts passing various filters. The values are:
| UnMapped | Number of reads that are not mapped (aligned) |
| Mapped | Number of reads that are mapped (aligned) |
| Duplicates | Number of reads that align to exactly the same place as another read |
| MapQPass | Number of reads with a mapping quality score greater than or equal to the specified threshold |
| MapQPassandDup | Number of reads that are mapped (aligned) and not duplicates |
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) flagtagcounts(exampleExp) flagtagcounts(QCsample(exampleExp,1))data(example_QCexperiment) flagtagcounts(exampleExp) flagtagcounts(QCsample(exampleExp,1))
Retrieve the estimated fragment length.
signature(object = "ChIPQCexperiment")Retrieve a vector of estimated fragments sizes, one for each sample in the experiment.
signature(object = "list")Retrieve a vector of estimated fragments sizes, one for each sample in a list of ChIPQCsample objects.
signature(object = "ChIPQCsample", width)Retrieve the estimated fragment length for a sample. If width is missing, the readlength derived from the bam file is used as the read length.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) fragmentlength(exampleExp) fragmentlength(QCsample(exampleExp,1))data(example_QCexperiment) fragmentlength(exampleExp) fragmentlength(QCsample(exampleExp,1))
Retrieve the fraction of reads in peaks
signature(object = "ChIPQCexperiment")Retrieve a vector of values representing the proportion of reads that overlap peaks for each sample in an experiment.
signature(object = "list")Retrieve a vector of values representing the proportion of reads that overlap peaks for each sample in a list of ChIPQCsample objects.
signature(object = "ChIPQCsample")Retrieve a value representing the proportion of reads that overlap the peaks for a sample.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) frip(exampleExp) frip(QCsample(exampleExp,1))data(example_QCexperiment) frip(exampleExp) frip(QCsample(exampleExp,1))
Retrieve the numbers of mapped reads.
signature(object = "ChIPQCexperiment")Retrieve a vector of the numbers of mapped (aligned) reads for each sample in an experiment.
signature(object = "list")Retrieve a vector of the numbers of mapped (aligned) reads for each sample in a list of ChIPQCsample objects.
signature(object = "ChIPQCsample")Retrieve the number of mapped (aligned) reads in a sample.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) mapped(exampleExp) mapped(QCsample(exampleExp,1))data(example_QCexperiment) mapped(exampleExp) mapped(QCsample(exampleExp,1))
Retrieve normalised average peak profiles
signature(object = "ChIPQCexperiment")Retrieve a matrix of normalised average peak signal data for all samples in a ChIP-seq experiment. Each column represents a sample, and each row a base pair position, centered on peak summits.
signature(object = "list")Retrieve a matrix of normalised average peak signal data for all samples in a list of ChIPQCsample objects. Each column represents a sample, and each row a base pair position, centered on peak summits.
signature(object = "ChIPQCsample")Retrieve a vector representing the normalised average peak profile for a sample. Each column represents a basepair position, centered on the peak summits.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) CTCFprofile = Normalisedaveragepeaksignal(QCsample(exampleExp,1)) length(CTCFprofile) plot(CTCFprofile,type='l',ylab="normalised mean pileup") allprofiles = Normalisedaveragepeaksignal(exampleExp) dim(allprofiles) for(i in 1:ncol(allprofiles)) lines(allprofiles[,i],col=i)data(example_QCexperiment) CTCFprofile = Normalisedaveragepeaksignal(QCsample(exampleExp,1)) length(CTCFprofile) plot(CTCFprofile,type='l',ylab="normalised mean pileup") allprofiles = Normalisedaveragepeaksignal(exampleExp) dim(allprofiles) for(i in 1:ncol(allprofiles)) lines(allprofiles[,i],col=i)
Retrieve peaks.
signature(object = "ChIPQCexperiment")Retrieve a GRangesList of the peaks associated with all the samples in an experiment.
signature(object = "list")Retrieve a GRangesList of the peaks associated with all the samples in a list of ChIPQCsample objects.
signature(object = "ChIPQCsample")Retrieve a GRanges object containing the peaks associated with a sample.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) expPeaks = peaks(exampleExp) length(expPeaks) peaks(QCsample(exampleExp,1))data(example_QCexperiment) expPeaks = peaks(exampleExp) length(expPeaks) peaks(QCsample(exampleExp,1))
Generate Cross-Coverage plots.
signature(object = "ChIPQCexperiment", method)Generate cross-coverage plots for all the samples in an experiment.
signature(object = "list", method)Generate cross-coverage plots for list of samples in an experiment.
signature(object = "ChIPQCsample", methods)Generate cross-coverage plots for a sample. Supported methods include:
| "Coverage" [default] | Coverage plot |
plotCC uses ggplot2 for plotting, and returns a ggplot2 plot dataframe.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) plotCC(exampleExp) plotCC(exampleExp,excludedBox=TRUE) plotCC(QCsample(exampleExp,1)) plotCC(QCsample(exampleExp)[1:4])data(example_QCexperiment) plotCC(exampleExp) plotCC(exampleExp,excludedBox=TRUE) plotCC(QCsample(exampleExp,1)) plotCC(QCsample(exampleExp)[1:4])
Generates correlation heatmap for ChIP samples.
signature(object = "ChIPQCexperiment", attributes, ...)Generate correlation heatmap, including clustering dendrogram, for all the samples in an experiment that are associated with a peakset.
| attributes | character string, or vector of character strings, representing metadata field names, for use in labeling |
| ... | additional parameters passed to dba.plotHeatmap
|
plotCorHeatmap uses dba.plotHeatmap for plotting.
Rory Stark and Thomas Carroll
ChIPQC-package, ChIPQCexperiment, dba.plotHeatmap
data(tamoxifen_QC) plotCorHeatmap(tamoxifen,attributes=c("Tissue","Condition","Replicate"))data(tamoxifen_QC) plotCorHeatmap(tamoxifen,attributes=c("Tissue","Condition","Replicate"))
Generate coverage histogram plot.
signature(object = "ChIPQCexperiment")Generate coverage histogram plots for all the samples in an experiment.
signature(object = "list")Generate coverage histogram plots for all the samples in a list of ChIPQCsamples.
signature(object = "ChIPQCsample")Generate coverage histogram plots for a sample.
Uses ggplot2 for plotting, and returns a ggplot2 plot dataframe.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) plotCoverageHist(exampleExp,facetBy=c("Tissue","Factor")) plotCoverageHist(QCsample(exampleExp,1))data(example_QCexperiment) plotCoverageHist(exampleExp,facetBy=c("Tissue","Factor")) plotCoverageHist(QCsample(exampleExp,1))
Generate fraction of reads in blacklist plot.
signature(object = "ChIPQCexperiment", type="barstacked",facet=T,
facetBy=c("Tissue","Factor"),AsPercent=TRUE)Generate fraction of reads in blacklist plots for all the samples in an experiment.
signature(object = "list", type="barstacked",facet=T,
facetBy=c("Sample"),AsPercent=TRUE)Generate fraction of reads in blacklist plots for all the samples in a list of ChIPQCsample objects..
signature(object = "ChIPQCsample", type="barstacked",AsPercent=TRUE)Generate fraction of reads in blacklist plots for a sample.
plotFribl uses ggplot2 for plotting, and returns a ggplot2 plot dataframe.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) plotFribl(exampleExp) plotFribl(QCsample(exampleExp,1))data(example_QCexperiment) plotFribl(exampleExp) plotFribl(QCsample(exampleExp,1))
Generate fraction of reads in peaks plot.
signature(object = "ChIPQCexperiment", type="barstacked",facet=T,
facetBy=c("Tissue","Factor"),AsPercent=TRUE)Generate fraction of reads in peaks plots for all the samples in an experiment.
signature(object = "list", type="barstacked",facet=T,
facetBy=c("Sample"),AsPercent=TRUE)Generate fraction of reads in peaks plots for all the samples in a list of ChIPQCsample objects.
signature(object = "ChIPQCsample",type="barstacked",facet=T,
facetBy=c("Tissue","Factor"),AsPercent=TRUE)Generate fraction of reads in peaks plots for a sample.
plotFrip usesggplot2 for plotting, and returns a ggplot2 plot dataframe.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) plotFrip(exampleExp) plotFrip(QCsample(exampleExp,1))data(example_QCexperiment) plotFrip(exampleExp) plotFrip(QCsample(exampleExp,1))
Generate peak profile plots.
signature(object = "ChIPQCexperiment", method)Generate peak profile plots for all the samples in an experiment.
signature(object = "list", method)Generate peak profile plots for all the samples in a list of ChIPQCsample objects..
signature(object = "ChIPQCsample", method)Generate peak profile plots for a sample.
plotPeakProfile uses ggplot2 for plotting, and returns a ggplot2 plot dataframe.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) plotCoverageHist(exampleExp,facetBy=c("Tissue","Factor")) plotCoverageHist(QCsample(exampleExp,1)) data(tamoxifen_QC) plotCoverageHist(tamoxifen,facetBy=c("Tissue","Condition"))data(example_QCexperiment) plotCoverageHist(exampleExp,facetBy=c("Tissue","Factor")) plotCoverageHist(QCsample(exampleExp,1)) data(tamoxifen_QC) plotCoverageHist(tamoxifen,facetBy=c("Tissue","Condition"))
Generate principal components analysis plot for ChIP samples.
signature(object = "ChIPQCexperiment", attributes, ...)Generate principal components analysis plot, for all the samples in an experiment that are associated with a peakset.
| attributes | character string, or vector of character strings, representing metadata field names, for use grouping samples by color. |
| ... | additional parameters passed to dba.plotPCA
|
plotPrincomp uses dba.plotPCA for plotting.
Rory Stark and Thomas Carroll
ChIPQC-package, ChIPQCexperiment, dba.plotPCA
data(tamoxifen_QC) plotPrincomp(tamoxifen,attributes=c("Condition"))data(tamoxifen_QC) plotPrincomp(tamoxifen,attributes=c("Condition"))
Generate reads in peaks plot.
signature(object = "ChIPQCexperiment", type="barstacked",facet=T,
facetBy=c("Tissue","Factor"))Generate reads in peaks plots for all the samples in an experiment.
signature(object = "list", type="barstacked",facet=T,
facetBy=c("Sample"))Generate reads in peaks plots for all the samples in a list of ChIPQCsample objects.
signature(object = "ChIPQCexperiment", type="barstacked",facet=T,
facetBy=c("Tissue","Factor"))Generate reads in peaks plots for all the samples in an experiment.
signature(object = "ChIPQCsample",type="barstacked",facet=T,
facetBy=c("Tissue","Factor"))Generate reads in peaks plots for a sample.
plotRap uses ggplot2 for plotting, and returns a ggplot2 plot dataframe.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) plotRap(exampleExp,facetBy=c("Tissue","Factor")) plotRap(QCsample(exampleExp,1))data(example_QCexperiment) plotRap(exampleExp,facetBy=c("Tissue","Factor")) plotRap(QCsample(exampleExp,1))
Generate relative enrichment of genomic features plot.
signature(object = "ChIPQCexperiment", facet=T,
facetBy=c("Tissue","Factor"))Generate relative enrichment of genomic features plots for all the samples in an experiment.
signature(object = "list",facet=T,
facetBy=c("Sample"))Generate relative enrichment of genomic features plots for all the samples in a list of ChIPQCsample objects.
signature(object = "ChIPQCsample")Generate relative enrichment of genomic features plots for a sample.
plotRegi uses ggplot2 for plotting, and returns a ggplot2 plot dataframe.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) plotRegi(exampleExp,facetBy=c("Tissue","Factor")) plotRegi(QCsample(exampleExp,1)) data(tamoxifen_QC) plotRegi(tamoxifen,facetBy=c("Tissue","Condition"))data(example_QCexperiment) plotRegi(exampleExp,facetBy=c("Tissue","Factor")) plotRegi(QCsample(exampleExp,1)) data(tamoxifen_QC) plotRegi(tamoxifen,facetBy=c("Tissue","Condition"))
Generate SSD metric plot. If blacklists supplied, will generate SSD prior and post blacklisting
signature(object = "ChIPQCexperiment", facet=T,
facetBy=c("Tissue","Factor"))Generate SSD metric plot for all samples in experiment. If blacklists supplied, will generate SSD prior and post blacklisting
signature(object = "list", facet=T,
facetBy=c("Tissue","Factor"))Generate SSD metric plot for list of samples in experiment. If blacklists supplied, will generate SSD prior and post blacklisting
signature(object = "ChIPQCsample")Generate SSD metric plot for single sample. If blacklists supplied, will generate SSD prior and post blacklisting
plotSSD uses ggplot2 for plotting, and returns a ggplot2 plot gg object.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) plotSSD(exampleExp,facetBy=c("Tissue","Factor")) plotSSD(QCsample(exampleExp,1)) plotSSD(QCsample(exampleExp)[1:3]) data(tamoxifen_QC) plotSSD(tamoxifen,facetBy=c("Tissue","Condition"))data(example_QCexperiment) plotSSD(exampleExp,facetBy=c("Tissue","Factor")) plotSSD(QCsample(exampleExp,1)) plotSSD(QCsample(exampleExp)[1:3]) data(tamoxifen_QC) plotSSD(tamoxifen,facetBy=c("Tissue","Condition"))
Retrieve an annotation description, or a processed annotation, from a ChIPQCexperiment object.
signature(object = "ChIPQCexperiment", bRetrieve=FALSE)Retrieve the annotation. If bRetrieve=FALSE (default), the character string describing the annotation is returned (currently only “hg19” is supported). If bRetrieve=TRUE, a processed annotation is returned (in the form of a list). This can be used in subsequent calls to ChIPQC and/or ChIPQCsample for efficiency purposes.
Rory Stark and Thomas Carroll
ChIPQC-package, ChIPQCsample, ChIPQCexperiment
data(example_QCexperiment) QCannotation(exampleExp)data(example_QCexperiment) QCannotation(exampleExp)
Retrieve the ChIPQCsample objects representing controls, or a specific ChIPQCsample representing the control for a specific sample, from a ChIPQCexperiment object.
signature(object = "ChIPQCexperiment", sampleID)Get the control sample (as a ChIPQCsample object) associated with a ChIP sample, or, if sampleID is missing, a list of all samples used as controls. sampleID is a character string or an integer.
Rory Stark and Thomas Carroll
ChIPQC-package, ChIPQCsample, ChIPQCexperiment
data(tamoxifen_QC) controls = QCcontrol(tamoxifen) length(controls) names(controls) controls[[1]] bt474control = QCcontrol(tamoxifen,"BT4741") bt474controldata(tamoxifen_QC) controls = QCcontrol(tamoxifen) length(controls) names(controls) controls[[1]] bt474control = QCcontrol(tamoxifen,"BT4741") bt474control
DBA-object object associated with an experimentRetrieve the DBA-object object associated with a ChIPQCexperiment object.
signature(object = "ChIPQCexperiment")Retrieves the DBA-object object associated with a ChIPQCexperiment. This object can be used with DiffBind functions to further analyse a ChIP-seq experiment, including performing a differential binding analysis.
Rory Stark and Thomas Carroll
ChIPQC-package, ChIPQCexperiment, DiffBind, dba
data(tamoxifen_QC) tamoxifenDBA = QCdba(tamoxifen) ## library(DiffBind) ## tamoxifenDBAdata(tamoxifen_QC) tamoxifenDBA = QCdba(tamoxifen) ## library(DiffBind) ## tamoxifenDBA
Retrieve metadata for a ChIPQCexperiment object.
signature(object = "ChIPQCexperiment")Retrieve a data frame containing metadata for all the samples in a ChIP-seq experiment represented by a ChIPQCexperiment object.
signature(object = "list")Retrieve a data frame containing metadata for all the samples in a list of ChIPQCsample objects.
Rory Stark and Thomas Carroll
ChIPQC-package, ChIPQCsample, ChIPQCexperiment
data(tamoxifen_QC) meta = QCmetadata(tamoxifen) metadata(tamoxifen_QC) meta = QCmetadata(tamoxifen) meta
Retrieves a consolidated set of QC metrics.
signature(object = "ChIPQCexperiment")Retrieves a matrix of QC metrics for all the samples in an experiment, with a column of values for each sample.
signature(object = "list")Retrieves a matrix of QC metrics for all the samples in a list of ChIPQCsample objects, with a column of values for each sample.
signature(object = "ChIPQCsample")Retrieves a vector of QC metrics for a sample.
Rory Stark and Thomas Carroll
ChIPQC-package, ChIPQCsample, ChIPQCexperiment
data(example_QCexperiment) QCmetrics(exampleExp) data(tamoxifen_QC) QCmetrics(tamoxifen) QCmetrics(QCsample(tamoxifen,1))data(example_QCexperiment) QCmetrics(exampleExp) data(tamoxifen_QC) QCmetrics(tamoxifen) QCmetrics(QCsample(tamoxifen,1))
Retrieves a list of ChIPQCsample objects, or one specific ChIPQCsample object, from a ChIPQCexperiment object.
signature(object = "ChIPQCexperiment", sampleID)If sampleID is missing or equal to 0, the full list of ChIPQCsample objects is returned. If sampleID is an integer n, the ChIPQCsample object corresponding to the nth sample is returned. If sampleID is a character string, the ChIPQCsample object corresponding to the sample with that ID is returned.
Rory Stark and Thomas Carroll
ChIPQC-package, ChIPQCsample, ChIPQCexperiment
data(example_QCexperiment) samples = QCsample(exampleExp) length(samples) names(samples) samples$CTCF_1data(example_QCexperiment) samples = QCsample(exampleExp) length(samples) names(samples) samples$CTCF_1
Retrieve read length values.
signature(object = "ChIPQCexperiment")Retrieve a vector of read length values, one for each sample in an experiment.
signature(object = "list")Retrieve a vector of read length values, one for each sample in a list of ChIPQCsample objects.
signature(object = "ChIPQCsample")Retrieve the read length value for a sample.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) readlength(exampleExp) readlength(QCsample(exampleExp,1))data(example_QCexperiment) readlength(exampleExp) readlength(QCsample(exampleExp,1))
Retrieve the cross coverage values when extending reads to the optimal fragment length.
signature(object = "ChIPQCexperiment")Retrieve a vector of cross-coverage values for all samples in a ChIP-seq experiment, when all reads are shifted by the optimal fragment length (the maximum cross-coverage value).
signature(object = "list")Retrieve a vector of cross-coverage values for all samples in a list of ChIPQCsample objects, when all reads are shifted by the optimal fragment length (the maximum cross-coverage value).
signature(object = "ChIPQCsample")Retrieve the cross-coverage value for a sample, when all reads are shifted by the optimal fragment length (the maximum cross-coverage value).
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) FragmentLengthCrossCoverage(exampleExp) FragmentLengthCrossCoverage(QCsample(exampleExp,1))data(example_QCexperiment) FragmentLengthCrossCoverage(exampleExp) FragmentLengthCrossCoverage(QCsample(exampleExp,1))
Retrieve the cross coverage values without extending reads.
signature(object = "ChIPQCexperiment")Retrieve a vector of cross-coverage values for all samples in a ChIP-seq experiment, with no shift.
signature(object = "list")Retrieve a vector of cross-coverage values for all samples in a list of ChIPQCsample objects, with no shift.
signature(object = "ChIPQCsample")Retrieve the cross-coverage value for a sample, with no shift.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) ReadLengthCrossCoverage(exampleExp) ReadLengthCrossCoverage(QCsample(exampleExp,1))data(example_QCexperiment) ReadLengthCrossCoverage(exampleExp) ReadLengthCrossCoverage(QCsample(exampleExp,1))
Retrieve the numbers of reads.
signature(object = "ChIPQCexperiment", bFiltered)Retrieve a vector of the numbers of reads for each sample in an experiment. If bFiltered=TRUE (or is missing), this will be the number of reads that pass the mapping quality filter for each sample. if bFiltered=FALSE, it will be the total number of reads for each sample.
signature(object = "list", bFiltered)Retrieve a vector of the numbers of reads for each sample in a list of ChIPQCsample objects. If bFiltered=TRUE (or is missing), this will be the number of reads that pass the mapping quality filter for each sample. if bFiltered=FALSE, it will be the total number of reads for each sample.
signature(object = "ChIPQCsample", bFiltered)Retrieve the number of reads for a sample. If bFiltered=TRUE (or is missing), this will be the number of reads that pass the mapping quality filter. if bFiltered=FALSE, it will be the total number of reads for the sample.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) reads(exampleExp) reads(QCsample(exampleExp,1))data(example_QCexperiment) reads(exampleExp) reads(QCsample(exampleExp,1))
Retrieve genomic profile information in terms of relative enrichment over background genomic distribution.
signature(object = "ChIPQCexperiment")Retrieve a matrix of relative enrichment values for a variety of genomic features. Each column represents the enrichment values for one sample in the experiment.
signature(object = "list")Retrieve a matrix of relative enrichment values for a variety of genomic features. Each column represents the enrichment values for one sample in a list of ChIPQCsample objects.
signature(object = "ChIPQCsample")Retrieve a vector of relative enrichment values for a variety of genomic features for a sample. Relative enrichment is computed as the proportion of reads overlapping a genomic feature type compared to the overall proportion of base pairs in the genome comprising those features. Genomic features include:
| 3UTRs | 3' UTRs |
| 5UTRs | 5' UTRs |
| Introns | Intronic (non-coding) portions of gene bodies |
| Transcripts | Transcribed regions, including exons |
| Promoters500 | 500bp regions immediately upstream of annotated TSSs |
| Promoters2000to500 | 2500bp regions from 2000bp immediately upstream of annotated TSSs to 500bp downstream |
| Promoters20000to2000 | 22000bp regions from 20000bp immediately upstream of annotated TSSs to 2000bp downstream |
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) genomicprofile = regi(exampleExp) heatmap(genomicprofile) regi(QCsample(exampleExp,1))data(example_QCexperiment) genomicprofile = regi(exampleExp) heatmap(genomicprofile) regi(QCsample(exampleExp,1))
Retrieve the relative cross-coverage values for a range of shift sizes
signature(object = "ChIPQCexperiment")Retrieve a vector of relative cross-coverage values for all samples in a ChIP-seq experiment, computed based on the maximal value (when extending the reads to the optimal fragment length) versus the cross-coverage values using non-extended reads.
signature(object = "list")Retrieve a vector of relative cross-coverage values for all samples in a list of ChIPQCsample objects, computed based on the maximal value (when extending the reads to the optimal fragment length) versus the cross-coverage values using non-extended reads.
signature(object = "ChIPQCsample")Retrieve the relative cross-coverage value for a sample, computed based on the maximal value (when extending the reads to the optimal fragment length) versus the cross-coverage values using non-extended reads.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) RelativeCrossCoverage(exampleExp) RelativeCrossCoverage(QCsample(exampleExp,1))data(example_QCexperiment) RelativeCrossCoverage(exampleExp) RelativeCrossCoverage(QCsample(exampleExp,1))
Retrieve the numbers of reads overlapping blacklisted regions.
signature(object = "ChIPQCexperiment")Retrieve a vector of the numbers of reads overlapping blacklisted regions for each sample in an experiment.
signature(object = "list")Retrieve a vector of the numbers of reads overlapping blacklisted regions for each sample in a list of ChIPQCsample objects.
signature(object = "ChIPQCsample")Retrieve the number of reads overlapping blacklisted regions in a sample.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) ribl(exampleExp) ribl(QCsample(exampleExp,1))data(example_QCexperiment) ribl(exampleExp) ribl(QCsample(exampleExp,1))
Retrieve the numbers of reads overlapping peaks.
signature(object = "ChIPQCexperiment")Retrieve a vector of the numbers of reads overlapping peaks for each sample in an experiment.
signature(object = "list")Retrieve a vector of the numbers of reads overlapping peaks for each sample in a list of ChIPQCsample objects.
signature(object = "ChIPQCsample")Retrieve the number of reads overlapping peaks in a sample.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) rip(exampleExp) rip(QCsample(exampleExp,1))data(example_QCexperiment) rip(exampleExp) rip(QCsample(exampleExp,1))
Retrieve SSD (squared sum of deviations) values of peak coverage density.
signature(object = "ChIPQCexperiment")Retrieve a vector of SSD values, one for each sample in an experiment.
signature(object = "list")Retrieve a vector of SSD values, one for each sample in a list of ChIPQCsample objects.
signature(object = "ChIPQCsample")Retrieve the SSD (squared sum of deviations) for a sample, computed from the standard deviation of the coveragehistogram.
uses the SSD calculation from the chipseq package.
Thomas Carroll and Rory Stark
ChIPQC-package, ChIPQCexperiment, ChIPQCsample
data(example_QCexperiment) ssd(exampleExp) ssd(QCsample(exampleExp,1))data(example_QCexperiment) ssd(exampleExp) ssd(QCsample(exampleExp,1))